View source: R/cvd_api_functions.R
| cvd_area_system_level | R Documentation |
Returns all available system levels for a specified time period.
cvd_area_system_level(time_period_id = 1)
time_period_id |
integer - the time period to return data for (compulsory) |
CVD Prevent API documentation: System levels per time period
tibble of system levels available for the time period
cvd_area_details(), cvd_area_unassigned(), cvd_area_search(), cvd_area_nested_subsystems(), cvd_area_flat_subsystems()
# list system levels for time period 4
cvd_area_system_level(time_period_id = 4) |>
dplyr::select(SystemLevelID, SystemLevelName)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.