View source: R/cvd_api_functions.R
| cvd_indicator_group | R Documentation |
Returns a single indicator group for a given group ID. An error will be
returned if there is no indicator group associated with the given ID.
IndicatorGroup is the primary key in the IndicatorGroup table, which also
contains IndicatorGroupName and IndicatorGroupTypeID. The group type ID
tells you what type of indicator group you're dealing with, e.g. a Priority
Group.
IndicatorGroupTypeID is the primary key of IndicatorGroupType and so
IndicatorGroupTypeName is the associated name for the given group type ID.
Finally, there is the array of indicators which are contained in this group,
including display orders for the given group.
cvd_indicator_group(indicator_group_id = 15)
indicator_group_id |
integer - the group to return data for (compulsory) |
CVD Prevent API documentation: Indicator group
Tibble of indicators grouped by indicator group
cvd_indicator_list(), cvd_indicator_metric_list(), cvd_indicator(),
cvd_indicator_tags(), cvd_indicator_details(), cvd_indicator_sibling(),
cvd_indicator_child_data(), cvd_indicator_data(), cvd_indicator_metric_data(),
cvd_indicator_raw_data(), cvd_indicator_nationalarea_metric_data(),
cvd_indicator_priority_groups(), cvd_indicator_pathway_group(), #
cvd_indicator_metric_timeseries(),
cvd_indicator_person_timeseries(), cvd_indicator_metric_systemlevel_comparison(),
cvd_indicator_metric_area_breakdown()
# list the indicators under Indicator Group ID 13 (Monitoring) which lists
# 'Key Question' Indicator Group indicators:
cvd_indicator_group(indicator_group_id = 13) |>
dplyr::select(IndicatorGroupID, IndicatorGroupName, IndicatorGroupTypeName,
IndicatorID, IndicatorName)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.